function F=surf_movie(mm,D)
% function to create surf movies 

% Input:   mm -     3-d "matrix" containing function values at different
%                   locations and times, mm=mm(x,y,t)
%          D  -     2x2 matrix with entries for spatial domain boundary points 
% 2017/05/13

if nargin<2
    D=[-1,1;-1,1]; % use spatial domain [-1,1]x[-1,1]
end
[nx,ny,nz]=size(mm);
xx=linspace(D(1,1),D(1,2),nx); % grid points in x-direction
yy=linspace(D(2,1),D(2,2),ny); % grid points in y-direction
[X,Y]=meshgrid(xx,yy); % create a 2-d grid

scrsz = get(0,'ScreenSize');
figure('Renderer','zbuffer','Position',[1 0.1*scrsz(4)/2 2.5*scrsz(4)/2 ...
    1.8*scrsz(4)/2])
surf(X,Y,mm(:,:,1),mm(:,:,1),'FaceColor','interp','EdgeColor','none',...
   'FaceLighting','gouraud'); colorbar
zmax=max(max(max(mm)));
zmin=min(min(min(mm)));
axis tight manual
zlim([zmin zmax])

caxis([zmin zmax])
set(gca,'NextPlot','replaceChildren');

F(nz)=struct('cdata',[],'colormap',[]);
F(1)=getframe(gcf);
for n=2:nz
    surf(X,Y,mm(:,:,n),mm(:,:,n-1),'FaceColor','interp','EdgeColor','none',...
   'FaceLighting','gouraud')
    F(n)=getframe(gcf);
end


